==> huaweicloudsdkgsl-3.0.74-py2.py3-none-any.whl: huaweicloudsdkgsl/v3/model/list_flow_by_sim_cards_req.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListFlowBySimCardsReq:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'iccids': 'list[str]'
    }

    attribute_map = {
        'iccids': 'iccids'
    }

    def __init__(self, iccids=None):
        """ListFlowBySimCardsReq - a model defined in huaweicloud sdk"""
        
        

        self._iccids = None
        self.discriminator = None

        self.iccids = iccids

    @property
    def iccids(self):
        """Gets the iccids of this ListFlowBySimCardsReq.

        ICCID列表,最大支持50

        :return: The iccids of this ListFlowBySimCardsReq.
        :rtype: list[str]
        """
        return self._iccids

    @iccids.setter
    def iccids(self, iccids):
        """Sets the iccids of this ListFlowBySimCardsReq.

        ICCID列表,最大支持50

        :param iccids: The iccids of this ListFlowBySimCardsReq.
        :type: list[str]
        """
        self._iccids = iccids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListFlowBySimCardsReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgsl-3.0.91-py2.py3-none-any.whl: huaweicloudsdkgsl/v3/model/list_flow_by_sim_cards_req.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListFlowBySimCardsReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'iccids': 'list[str]'
    }

    attribute_map = {
        'iccids': 'iccids'
    }

    def __init__(self, iccids=None):
        """ListFlowBySimCardsReq

        The model defined in huaweicloud sdk

        :param iccids: ICCID列表,最大支持50
        :type iccids: list[str]
        """
        
        

        self._iccids = None
        self.discriminator = None

        self.iccids = iccids

    @property
    def iccids(self):
        """Gets the iccids of this ListFlowBySimCardsReq.

        ICCID列表,最大支持50

        :return: The iccids of this ListFlowBySimCardsReq.
        :rtype: list[str]
        """
        return self._iccids

    @iccids.setter
    def iccids(self, iccids):
        """Sets the iccids of this ListFlowBySimCardsReq.

        ICCID列表,最大支持50

        :param iccids: The iccids of this ListFlowBySimCardsReq.
        :type iccids: list[str]
        """
        self._iccids = iccids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListFlowBySimCardsReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
